DROP TABLE IF EXISTS somaticVariant;
CREATE TABLE somaticVariant
(   id int NOT NULL AUTO_INCREMENT,
    modified DATETIME NOT NULL,
    sampleId varchar(255) NOT NULL,
    chromosome varchar(255) NOT NULL,
    position int not null,
    filter varchar(255) NOT NULL,
    type varchar(255) NOT NULL,
    ref varchar(255) NOT NULL,
    alt varchar(255) NOT NULL,
    gene varchar(255) NOT NULL,
    genesEffected int not null,
    cosmicId varchar(255) NOT NULL,
    dbsnpId varchar(255) NOT NULL,
    worstEffectTranscript varchar(255) NOT NULL,
    worstEffect varchar(255) NOT NULL,
    worstCodingEffect varchar(255) NOT NULL,
    canonicalEffect varchar(255) NOT NULL,
    canonicalCodingEffect varchar(255) NOT NULL,
    microhomology varchar(255) NOT NULL,
    repeatSequence varchar(255) NOT NULL,
    repeatCount int NOT NULL,
    alleleReadCount int NOT NULL,
    totalReadCount int NOT NULL,
    adjustedVaf DOUBLE PRECISION NOT NULL,
    adjustedCopyNumber DOUBLE PRECISION NOT NULL,
    highConfidence BOOLEAN NOT NULL,
    trinucleotideContext varchar(3) NOT NULL,
    clonality varchar(455) NOT NULL,
    biallelic BOOLEAN NOT NULL,
    hotspot BOOLEAN NOT NULL,
    mappability DOUBLE PRECISION NOT NULL,
    germlineStatus varchar(255) NOT NULL,
    minorAllelePloidy DOUBLE PRECISION NOT NULL,
    PRIMARY KEY (id),
    INDEX(sampleId),
    INDEX(filter),
    INDEX(type),
    INDEX(gene)
);


DROP TABLE IF EXISTS purityRange;
CREATE TABLE purityRange
(   id int NOT NULL AUTO_INCREMENT,
    modified DATETIME NOT NULL,
    sampleId varchar(255) NOT NULL,
    purity DOUBLE PRECISION not null,
    normFactor DOUBLE PRECISION not null,
    score DOUBLE PRECISION not null,
    ploidy DOUBLE PRECISION not null,
    diploidProportion DOUBLE PRECISION not null,
    PRIMARY KEY (id),
    INDEX(sampleId)
);

DROP TABLE IF EXISTS copyNumber;
CREATE TABLE copyNumber
(   id int NOT NULL AUTO_INCREMENT,
    modified DATETIME NOT NULL,
    sampleId varchar(255) NOT NULL,
    chromosome varchar(255) NOT NULL,
    start int not null,
    end int not null,
    segmentStartSupport varchar(255) NOT NULL,
    segmentEndSupport varchar(255) NOT NULL,
    bafCount int not null,
    observedBaf DOUBLE PRECISION not null,
    actualBaf DOUBLE PRECISION not null,
    copyNumber DOUBLE PRECISION not null,
    copyNumberMethod varchar(255) NOT NULL,
    PRIMARY KEY (id),
    INDEX(sampleId)
);

DROP TABLE IF EXISTS copyNumberGermline;
CREATE TABLE copyNumberGermline
(   id int NOT NULL AUTO_INCREMENT,
    modified DATETIME NOT NULL,
    sampleId varchar(255) NOT NULL,
    chromosome varchar(255) NOT NULL,
    start int not null,
    end int not null,
    segmentStartSupport varchar(255) NOT NULL,
    segmentEndSupport varchar(255) NOT NULL,
    bafCount int not null,
    observedBaf DOUBLE PRECISION not null,
    actualBaf DOUBLE PRECISION not null,
    copyNumber DOUBLE PRECISION not null,
    copyNumberMethod varchar(255) NOT NULL,
    PRIMARY KEY (id),
    INDEX(sampleId)
);

DROP TABLE IF EXISTS copyNumberRegion;
CREATE TABLE copyNumberRegion
(   id int NOT NULL AUTO_INCREMENT,
    modified DATETIME NOT NULL,
    sampleId varchar(255) NOT NULL,
    chromosome varchar(255) NOT NULL,
    start int not null,
    end int not null,
    germlineStatus varchar(255) NOT NULL,
    svCluster BOOLEAN NOT NULL,
    ratioSupport BOOLEAN NOT NULL,
    segmentStartSupport varchar(255) NOT NULL,
    bafCount int not null,
    observedBaf DOUBLE PRECISION not null,
    observedTumorRatio DOUBLE PRECISION not null,
    observedNormalRatio DOUBLE PRECISION not null,
    observedTumorRatioCount int not null,
    gcContent DOUBLE PRECISION not null,
    modelPloidy int not null,
    modelBaf DOUBLE PRECISION not null,
    modelTumorRatio DOUBLE PRECISION not null,
    actualTumorBaf DOUBLE PRECISION not null,
    actualTumorCopyNumber DOUBLE PRECISION not null,
    refNormalisedTumorCopyNumber DOUBLE PRECISION not null,
    cnvDeviation DOUBLE PRECISION not null,
    bafDeviation DOUBLE PRECISION not null,
    totalDeviation DOUBLE PRECISION not null,
    ploidyPenalty DOUBLE PRECISION not null,
    fittedBaf DOUBLE PRECISION not null,
    fittedCopyNumber DOUBLE PRECISION not null,
    PRIMARY KEY (id),
    INDEX(sampleId)
);

DROP TABLE IF EXISTS geneCopyNumber;
CREATE TABLE geneCopyNumber
(   id int NOT NULL AUTO_INCREMENT,
    modified DATETIME NOT NULL,
    sampleId varchar(255) NOT NULL,
    chromosome varchar(255) NOT NULL,
    start int not null,
    end int not null,
    gene varchar(255) NOT NULL,
    chromosomeBand varchar(255) NOT NULL,
    transcriptId varchar(255) NOT NULL,
    transcriptVersion int not null,
    minCopyNumber DOUBLE PRECISION not null,
    maxCopyNumber DOUBLE PRECISION not null,
    somaticRegions int not null,
    germlineHomRegions int not null,
    germlineHetRegions int not null,
    minRegions int not null,
    minRegionStart int not null,
    minRegionEnd int not null,
    minRegionStartSupport varchar(255) NOT NULL,
    minRegionEndSupport varchar(255) NOT NULL,
    minRegionMethod varchar(255) NOT NULL,
    nonsenseBiallelicVariants int not null,
    nonsenseNonBiallelicVariants int not null,
    nonsenseNonBiallelicPloidy DOUBLE PRECISION not null,
    spliceBiallelicVariants int not null,
    spliceNonBiallelicVariants int not null,
    spliceNonBiallelicPloidy DOUBLE PRECISION not null,
    missenseBiallelicVariants int not null,
    missenseNonBiallelicVariants int not null,
    missenseNonBiallelicPloidy DOUBLE PRECISION not null,
    minMinorAllelePloidy DOUBLE PRECISION not null,
    PRIMARY KEY (id),
    INDEX(sampleId),
    INDEX(gene)
);

DROP TABLE IF EXISTS structuralVariant;
CREATE TABLE structuralVariant
(   id int NOT NULL AUTO_INCREMENT,
    modified DATETIME NOT NULL,
    sampleId varchar(255) NOT NULL,
    startChromosome varchar(255) NOT NULL,
    endChromosome varchar(255) NOT NULL,
    startPosition int not null,
    endPosition int not null,
    startOrientation tinyint not null,
    endOrientation tinyint not null,
    startHomologySequence varchar(255) not null,
    endHomologySequence varchar(255) not null,
    startAF DOUBLE PRECISION,
    endAF DOUBLE PRECISION,
    ploidy DOUBLE PRECISION,
    adjustedStartAF DOUBLE PRECISION,
    adjustedEndAF DOUBLE PRECISION,
    adjustedStartCopyNumber DOUBLE PRECISION,
    adjustedEndCopyNumber DOUBLE PRECISION,
    adjustedStartCopyNumberChange DOUBLE PRECISION,
    adjustedEndCopyNumberChange DOUBLE PRECISION,
    insertSequence varchar(2048) not null,
    type varchar(255) NOT NULL,
    filter varchar(255) NOT NULL,
    PRIMARY KEY (id),
    INDEX(sampleId)
);

DROP TABLE IF EXISTS structuralVariantBreakend;
CREATE TABLE structuralVariantBreakend
(   id INT UNSIGNED NOT NULL AUTO_INCREMENT,
    modified DATETIME NOT NULL,
    structuralVariantId INT NOT NULL,
    isStartEnd BOOLEAN NOT NULL,
    gene VARCHAR(512) NOT NULL, # length here comes from ensembl db schema
    geneId VARCHAR(128) NOT NULL, # length here comes from ensembl db schema
    transcriptId VARCHAR(128) NOT NULL, # length here comes from ensembl db schema
    isCanonicalTranscript BOOLEAN NOT NULL,
    strand TINYINT NOT NULL,
    exonRankUpstream TINYINT UNSIGNED,
    exonRankDownstream TINYINT UNSIGNED,
    exonPhaseUpstream TINYINT,
    exonPhaseDownstream TINYINT,
    exonMax TINYINT NOT NULL,
    PRIMARY KEY (id),
    INDEX(structuralVariantId),
    INDEX(gene),
    INDEX(geneId),
    INDEX(transcriptId)
);

DROP TABLE IF EXISTS structuralVariantDisruption;
CREATE TABLE structuralVariantDisruption
(   id INT UNSIGNED NOT NULL AUTO_INCREMENT,
    breakendId INT UNSIGNED NOT NULL,
    isReported BOOLEAN NOT NULL,
    PRIMARY KEY (id),
    INDEX(breakendId)
);

DROP TABLE IF EXISTS structuralVariantFusion;
CREATE TABLE structuralVariantFusion
(   id INT UNSIGNED NOT NULL AUTO_INCREMENT,
    fivePrimeBreakendId INT UNSIGNED NOT NULL,
    threePrimeBreakendId INT UNSIGNED NOT NULL,
    isReported BOOLEAN NOT NULL,
    PRIMARY KEY (id),
    INDEX(fivePrimeBreakendId),
    INDEX(threePrimeBreakendId)
);
